pub struct AuditLog { /* private fields */ }Expand description
Append-only audit logger that writes to a local JSONL file.
Implementations
Sourceimpl AuditLog
impl AuditLog
pub fn new() -> Result<Self>
Sourcepub fn with_path(path: PathBuf) -> Result<Self>
pub fn with_path(path: PathBuf) -> Result<Self>
Construct an AuditLog at a caller-provided path. Used by tests so they
don’t pollute the real audit log at ~/.local/share/audex/audit/audit.jsonl.
pub fn log(&self, session_id: &str, event: AuditEvent) -> Result<()>
pub fn log_with_provider( &self, session_id: &str, provider: &str, event: AuditEvent, ) -> Result<()>
pub fn log_session_created(&self, session: &Session) -> Result<()>
pub fn log_session_ended( &self, session: &Session, exit_code: Option<i32>, ) -> Result<()>
Sourcepub fn read(&self, session_id: Option<&str>) -> Result<Vec<AuditEntry>>
pub fn read(&self, session_id: Option<&str>) -> Result<Vec<AuditEntry>>
Read all audit entries, optionally filtered by session ID.
Sourcepub fn read_filtered(
&self,
session_id: Option<&str>,
provider: Option<&str>,
) -> Result<Vec<AuditEntry>>
pub fn read_filtered( &self, session_id: Option<&str>, provider: Option<&str>, ) -> Result<Vec<AuditEntry>>
Read audit entries with optional session ID and provider filters.
Sourcepub fn verify(&self) -> Result<VerificationResult>
pub fn verify(&self) -> Result<VerificationResult>
Verify the integrity of the audit log using chain HMACs.
pub fn path(&self) -> &PathBuf