pub struct CredentialIssuer { /* private fields */ }Expand description
Issues scoped, short-lived AWS credentials via STS AssumeRole.
Implementations
Sourceimpl CredentialIssuer
impl CredentialIssuer
pub async fn new() -> Result<Self>
pub async fn with_region(region: Option<&str>) -> Result<Self>
Sourcepub async fn issue(
&self,
session: &Session,
policy: &ScopedPolicy,
ttl: Duration,
) -> Result<TempCredentials>
pub async fn issue( &self, session: &Session, policy: &ScopedPolicy, ttl: Duration, ) -> Result<TempCredentials>
Assume a role with an inline policy that restricts permissions to the scoped policy. Optionally attaches a permissions boundary ARN as an additional ceiling.
Sourcepub async fn issue_with_boundary(
&self,
session: &Session,
policy: &ScopedPolicy,
ttl: Duration,
permissions_boundary: Option<&str>,
) -> Result<TempCredentials>
pub async fn issue_with_boundary( &self, session: &Session, policy: &ScopedPolicy, ttl: Duration, permissions_boundary: Option<&str>, ) -> Result<TempCredentials>
Assume a role with an inline policy and optional permissions boundary.
Sourcepub async fn issue_full(
&self,
session: &Session,
policy: &ScopedPolicy,
ttl: Duration,
permissions_boundary: Option<&str>,
network: Option<&NetworkPolicy>,
) -> Result<TempCredentials>
pub async fn issue_full( &self, session: &Session, policy: &ScopedPolicy, ttl: Duration, permissions_boundary: Option<&str>, network: Option<&NetworkPolicy>, ) -> Result<TempCredentials>
Assume a role with inline policy, optional boundary, and optional network conditions.